@@ -20,19 +20,20 @@
  * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-app.filter('calendarFilter', [
-	function() {
-		'use strict';
-		return function (item) {
-			var filter = [];
-			if (item.length > 0) {
-				for (var i = 0; i < item.length; i++) {
-					if (item[i].writable === true) {
-						filter.push(item[i]);
-					}
-				}
+app.filter('calendarFilter', function() {
+	'use strict';
+
+	return function (calendars) {
+		if (!Array.isArray(calendars)) {
+			return [];
+		}
+
+		return calendars.filter(function(element) {
+			if (typeof element !== 'object') {
+				return false;
+			} else {
+				return element.isWritable();
 			}
-			return filter;
-		};
-	}
-]);
+		});
+	};
+});
