@@ -20,32 +20,30 @@
  * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-app.filter('importCalendarFilter',
-	function () {
-		'use strict';
+app.filter('importCalendarFilter', function () {
+	'use strict';
 
-		return function (calendars, file) {
-			var possibleCalendars = [];
+	return function (calendars, file) {
+		if (!Array.isArray(calendars) || typeof file !== 'object' || !file || typeof file.splittedICal !== 'object' || !file.splittedICal) {
+			return [];
+		}
 
-			if (typeof file.split === 'undefined') {
-				return possibleCalendars;
+		var events = file.splittedICal.vevents.length,
+			journals = file.splittedICal.vjournals.length,
+			todos = file.splittedICal.vtodos.length;
+
+		return calendars.filter(function(calendar) {
+			if (events !== 0 && !calendar.components.vevent) {
+				return false;
+			}
+			if (journals !== 0 && !calendar.components.vjournal) {
+				return false;
+			}
+			if (todos !== 0 && !calendar.components.vtodo) {
+				return false;
 			}
 
-			angular.forEach(calendars, function(calendar) {
-				if (file.split.vevent.length !== 0 && !calendar.components.vevent) {
-					return;
-				}
-				if (file.split.vjournal.length !== 0 && !calendar.components.vjournal) {
-					return;
-				}
-				if (file.split.vtodo.length !== 0 && !calendar.components.vtodo) {
-					return;
-				}
-
-				possibleCalendars.push(calendar.url);
-			});
-
-			return possibleCalendars;
-		};
-	}
-);
+			return true;
+		});
+	};
+});
