@@ -111,7 +111,7 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 					continue;
 				}
 
-				var calendar = new Calendar(body.href, props);
+				var calendar = Calendar(body.href, props);
 				calendars.push(calendar);
 			}
 
@@ -144,7 +144,7 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 				return;
 			}
 
-			return new Calendar(body.href, props);
+			return Calendar(body.href, props);
 		});
 	};
 
@@ -222,8 +222,11 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 		var dProp = xmlDoc.createElement('d:prop');
 		dSet.appendChild(dProp);
 
-		var updatedProperties = calendar.updatedProperties;
-		calendar.resetUpdatedProperties();
+		var updatedProperties = calendar.getUpdated();
+		if (updatedProperties.length === 0) {
+			//nothing to do here
+			return calendar;
+		}
 		for (var i=0; i < updatedProperties.length; i++) {
 			dProp.appendChild(this._createXMLForProperty(
 				xmlDoc,
@@ -232,6 +235,8 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 			));
 		}
 
+		calendar.resetUpdated();
+
 		var url = calendar.url;
 		var body = this._xmls.serializeToString(dPropUpdate);
 		var headers = {
@@ -295,13 +300,13 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 			if (response.status === 200) {
 				if (!existingShare) {
 					if (shareType === OC.Share.SHARE_TYPE_USER) {
-						calendar.sharedWith.users.push({
+						calendar.shares.users.push({
 							id: shareWith,
 							displayname: shareWith,
 							writable: writable
 						});
 					} else if (shareType === OC.Share.SHARE_TYPE_GROUP) {
-						calendar.sharedWith.groups.push({
+						calendar.shares.groups.push({
 							id: shareWith,
 							displayname: shareWith,
 							writable: writable
@@ -339,11 +344,11 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 		return DavClient.request('POST', calendar.url, headers, body).then(function(response) {
 			if (response.status === 200) {
 				if (shareType === OC.Share.SHARE_TYPE_USER) {
-					calendar.sharedWith.users = calendar.sharedWith.users.filter(function(user) {
+					calendar.shares.users = calendar.shares.users.filter(function(user) {
 						return user.id !== shareWith;
 					});
 				} else if (shareType === OC.Share.SHARE_TYPE_GROUP) {
-					calendar.sharedWith.groups = calendar.sharedWith.groups.filter(function(groups) {
+					calendar.shares.groups = calendar.shares.groups.filter(function(groups) {
 						return groups.id !== shareWith;
 					});
 				}
@@ -368,7 +373,7 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 				return dDisplayname;
 
 			case 'order':
-				var aOrder = xmlDoc.createElement('a:calendar-color');
+				var aOrder = xmlDoc.createElement('a:calendar-order');
 				aOrder.textContent = value;
 				return aOrder;
 
@@ -396,7 +401,6 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 		this._getACLFromResponse(props);
 
 		var simple = {
-			enabled: props['{' + DavClient.NS_OWNCLOUD + '}calendar-enabled'] === '1',
 			displayname: props['{' + DavClient.NS_DAV + '}displayname'],
 			color: props['{' + DavClient.NS_APPLE + '}calendar-color'],
 			order: props['{' + DavClient.NS_APPLE + '}calendar-order'],
@@ -407,7 +411,7 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 			},
 			owner: null,
 			shareable: props.canWrite,
-			sharedWith: {
+			shares: {
 				users: [],
 				groups: []
 			},
@@ -449,13 +453,13 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 				readWrite = readWrite.length !== 0;
 
 				if (href.startsWith('principal:principals/users/')) {
-					simple.sharedWith.users.push({
+					simple.shares.users.push({
 						id: href.substr(27),
 						displayname: href.substr(27),
 						writable: readWrite
 					});
 				} else if (href.startsWith('principal:principals/groups/')) {
-					simple.sharedWith.groups.push({
+					simple.shares.groups.push({
 						id: href.substr(28),
 						displayname: href.substr(28),
 						writable: readWrite
@@ -464,6 +468,26 @@ app.service('CalendarService', ['DavClient', 'Calendar', function(DavClient, Cal
 			}
 		}
 
+		if (typeof props['{' + DavClient.NS_OWNCLOUD + '}calendar-enabled'] === 'undefined') {
+			if (typeof simple.owner !== 'undefined') {
+				simple.enabled = simple.owner === oc_current_user;
+			} else {
+				simple.enabled = false;
+			}
+		} else {
+			simple.enabled = (props['{' + DavClient.NS_OWNCLOUD + '}calendar-enabled'] === '1');
+		}
+
+		if (typeof simple.color !== 'undefined') {
+			if (simple.color.length === 9) {
+				simple.color = simple.color.substr(0,7);
+			}
+		} else {
+			simple.color = '#1d2d44';
+		}
+
+		simple.writableProperties = (oc_current_user === simple.owner) && simple.writable;
+
 		return simple;
 	};
 
